<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 */

namespace AuthStack\SP\Errors;

/**
 * Class InvalidIssuerException
 * @package AuthStack\SP
 *
 *
 *          This exception is thrown when the issuer of SAML response doesn't match what SP expects.
 *          Value to be checked is controlled via configuration key IdP.entityId
 *
 *
 */
class InvalidIssuerException extends \Exception
{}